import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 物品类型服务对象基类
 *
 * @export
 * @class EMItemTypeServiceBase
 * @extends {EntityServie}
 */
export default class EMItemTypeServiceBase extends EntityService {

    /**
     * Creates an instance of  EMItemTypeServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EMItemTypeServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EMItemTypeServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='emitemtype';
        this.APPDEKEY = 'emitemtypeid';
        this.APPDENAME = 'emitemtypes';
        this.APPDETEXT = 'emitemtypename';
        this.APPNAME = 'eamweb';
        this.SYSTEMNAME = 'eam_practice01';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/emitemtypes/${context.emitemtype}/select`,isloading);
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/emitemtypes/getdraft`,isloading);
        res.data.emitemtype = data.emitemtype;
            this.tempStorage.setItem(context.srfsessionkey+'_emitemtypes',JSON.stringify(res.data.emitemtypes));
        return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/emitemtypes/${context.emitemtype}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_emitemtypes',JSON.stringify(res.data.emitemtypes));
            return res;

    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let emitemtypesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes'),'undefined')){
            emitemtypesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes') as any);
            if(emitemtypesData && emitemtypesData.length && emitemtypesData.length > 0){
                emitemtypesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.emitemtypeid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.emitemtypes = emitemtypesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/emitemtypes/${context.emitemtype}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_emitemtypes',JSON.stringify(res.data.emitemtypes));
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/emitemtypes/${context.emitemtype}/checkkey`,data,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let emitemtypesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes'),'undefined')){
            emitemtypesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes') as any);
            if(emitemtypesData && emitemtypesData.length && emitemtypesData.length > 0){
                emitemtypesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.emitemtypeid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.emitemtypes = emitemtypesData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/emitemtypes`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_emitemtypes',JSON.stringify(res.data.emitemtypes));
        return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/emitemtypes/${context.emitemtype}`,isloading);

    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let emitemtypesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes'),'undefined')){
            emitemtypesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_emitemtypes') as any);
            if(emitemtypesData && emitemtypesData.length && emitemtypesData.length > 0){
                emitemtypesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.emitemtypeid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.emitemtypes = emitemtypesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/emitemtypes/${context.emitemtype}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_emitemtypes',JSON.stringify(res.data.emitemtypes));
            return res;
    }

    /**
     * FetchItemType接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async FetchItemType(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/emitemtypes/fetchitemtype`,tempData,isloading);
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTypeServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/emitemtypes/fetchdefault`,tempData,isloading);
    }
}